==> senior_design_system-0.28.2.tar.gz: example/lib/pages/slider_dots.example.dart <==
import 'package:flutter/material.dart';

import 'package:provider/provider.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class SliderDotsExample extends StatefulWidget {
  const SliderDotsExample({Key? key}) : super(key: key);

  @override
  _SliderDotsExampleState createState() => _SliderDotsExampleState();
}

class _SliderDotsExampleState extends State<SliderDotsExample> {
  final length = 13;
  int _currentPage = 0;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Slider Dots',
      child: Padding(
        padding: const EdgeInsets.symmetric(
          horizontal: SeniorSpacing.xsmall,
          vertical: SeniorSpacing.normal,
        ),
        child: Column(
          children: [
            SeniorSliderDots(
              currentPage: _currentPage,
              length: length,
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                SeniorIconButton(
                  icon: FontAwesomeIcons.arrowLeft,
                  onTap: () {
                    if (_currentPage > 0) {
                      setState(() {
                        _currentPage--;
                      });
                    }
                  },
                  size: SeniorIconButtonSize.small,
                  type: SeniorIconButtonType.primary,
                ),
                SeniorIconButton(
                  icon: FontAwesomeIcons.arrowRight,
                  onTap: () {
                    if (_currentPage < length - 1) {
                      setState(() {
                        _currentPage++;
                      });
                    }
                  },
                  size: SeniorIconButtonSize.small,
                  type: SeniorIconButtonType.primary,
                ),
              ],
            ),
            Consumer<ThemeRepository>(
              builder: (context, repository, child) => Text(
                '$_currentPage',
                style: SeniorTypography.body(
                  color: repository.isLightTheme() ? SeniorColors.pureBlack : SeniorColors.grayscale0,
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}

==> senior_design_system-2.2.16.tar.gz: example/lib/pages/slider_dots.example.dart <==
import 'package:flutter/material.dart';

import 'package:provider/provider.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class SliderDotsExample extends StatefulWidget {
  const SliderDotsExample({Key? key}) : super(key: key);

  @override
  _SliderDotsExampleState createState() => _SliderDotsExampleState();
}

class _SliderDotsExampleState extends State<SliderDotsExample> {
  final length = 13;
  int _currentPage = 0;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Slider Dots',
      child: Padding(
        padding: const EdgeInsets.symmetric(
          horizontal: SeniorSpacing.xsmall,
          vertical: SeniorSpacing.normal,
        ),
        child: Column(
          children: [
            SeniorSliderDots(
              currentPage: _currentPage,
              length: length,
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                SeniorIconButton(
                  icon: FontAwesomeIcons.arrowLeft,
                  onTap: () {
                    if (_currentPage > 0) {
                      setState(() {
                        _currentPage--;
                      });
                    }
                  },
                  size: SeniorIconButtonSize.small,
                  type: SeniorIconButtonType.primary,
                ),
                SeniorIconButton(
                  icon: FontAwesomeIcons.arrowRight,
                  onTap: () {
                    if (_currentPage < length - 1) {
                      setState(() {
                        _currentPage++;
                      });
                    }
                  },
                  size: SeniorIconButtonSize.small,
                  type: SeniorIconButtonType.primary,
                ),
              ],
            ),
            Consumer<ThemeRepository>(
              builder: (context, repository, child) => SeniorText.body('$_currentPage'),
            ),
          ],
        ),
      ),
    );
  }
}
